'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var process = require('process');
var os = require('os');
var path = require('path');
var fs = require('fs');

function _interopNamespace(e) {
  if (e && e.__esModule) return e;
  var n = Object.create(null);
  if (e) {
    Object.keys(e).forEach(function (k) {
      if (k !== 'default') {
        var d = Object.getOwnPropertyDescriptor(e, k);
        Object.defineProperty(n, k, d.get ? d : {
          enumerable: true,
          get: function () { return e[k]; }
        });
      }
    });
  }
  n["default"] = e;
  return Object.freeze(n);
}

var path__namespace = /*#__PURE__*/_interopNamespace(path);

/**
 * Environment Key.
 */
let EnvironmentKey;

(function (EnvironmentKey) {
  EnvironmentKey["ScwConfigPath"] = "SCW_CONFIG_PATH";
  EnvironmentKey["ScwAccessKey"] = "SCW_ACCESS_KEY";
  EnvironmentKey["ScwSecretKey"] = "SCW_SECRET_KEY";
  EnvironmentKey["ScwAPIURL"] = "SCW_API_URL";
  EnvironmentKey["ScwDefaultOrganizationId"] = "SCW_DEFAULT_ORGANIZATION_ID";
  EnvironmentKey["ScwDefaultProjectId"] = "SCW_DEFAULT_PROJECT_ID";
  EnvironmentKey["ScwDefaultRegion"] = "SCW_DEFAULT_REGION";
  EnvironmentKey["ScwDefaultZone"] = "SCW_DEFAULT_ZONE";
})(EnvironmentKey || (EnvironmentKey = {}));

/**
 * Gets the Scaleway directory.
 *
 * @returns The path to the Scaleway diretory
 *
 * @internal
 */

const getScwConfigurationDirectory = () => {
  const xdgConfigPath = process.env.XDG_CONFIG_HOME;
  if (typeof xdgConfigPath === 'string' && xdgConfigPath.length > 0) return path__namespace.join(xdgConfigPath, 'scw');
  return path__namespace.join(os.homedir(), '.config', 'scw');
};
/**
 * Gets the configuration file path.
 *
 * @returns The path to the configuration file
 *
 * @internal
 */

const resolveConfigurationFilePath = () => {
  // Try path defined by user in env variables
  const envFilePath = process.env[EnvironmentKey.ScwConfigPath];
  if (typeof envFilePath === 'string' && envFilePath.length > 0) return envFilePath; // or fallback on the default path

  return path__namespace.join(getScwConfigurationDirectory(), 'config.yaml');
};

const STRIP_COMMENT_REGEX = /(^|\s)[;#]/;
const DETECT_SECTION_REGEX = /^\s*([^]+):\s*$/;
const DETECT_ITEM_REGEX = /^\s*(.+?)\s*:\s*(.+?)\s*$/;
/**
 * Converts Yaml to configuration map.
 *
 * @param input - Yaml string
 * @returns The configuration map
 *
 * @internal
 */

const convertYamlToConfiguration = input => {
  let foundProfilesKey = false;
  let currentSection = 'default';
  const map = {};

  if (typeof input !== 'string') {
    return map;
  }

  input.split(/\r?\n/).forEach(rawLine => {
    // remove comments
    const line = rawLine.split(STRIP_COMMENT_REGEX)[0]; // parse sections

    const newSection = DETECT_SECTION_REGEX.exec(line);

    if (newSection) {
      currentSection = undefined;

      if (newSection[1] === 'profiles') {
        foundProfilesKey = true;
      } else if (foundProfilesKey === true) {
        [, currentSection] = newSection;
      }
    } // parse items
    else if (currentSection) {
      const item = DETECT_ITEM_REGEX.exec(line);

      if (item) {
        if (typeof map[currentSection] !== 'object') {
          map[currentSection] = {};
        }
        [,, map[currentSection][item[1]]] = item;
      }
    }
  });
  return map;
};
/**
 * Loads configuration from a file.
 *
 * @param filePath - Path to the configuration file
 * @returns The configuration
 *
 * @throws Error
 * Thrown if the file doesn't exist.
 *
 * @internal
 */

const loadConfigurationFromFile = filePath => {
  // `readFileSync` returns a string when encoding option is specified.
  // {@link https://nodejs.org/api/fs.html#fs_fs_readfilesync_path_options}
  const fileContent = fs.readFileSync(filePath, 'utf-8');
  return convertYamlToConfiguration(fileContent);
};

/**
 * Loads profile from environment values.
 *
 * @returns The profile filled with values found in the environment
 *
 * @public
 */

const loadProfileFromEnvironmentValues = () => ({
  accessKey: process.env[EnvironmentKey.ScwAccessKey],
  apiURL: process.env[EnvironmentKey.ScwAPIURL],
  defaultOrganizationId: process.env[EnvironmentKey.ScwDefaultOrganizationId],
  defaultProjectId: process.env[EnvironmentKey.ScwDefaultProjectId],
  defaultRegion: process.env[EnvironmentKey.ScwDefaultRegion],
  defaultZone: process.env[EnvironmentKey.ScwDefaultZone],
  secretKey: process.env[EnvironmentKey.ScwSecretKey]
});
/**
 * Loads profile from configuration file.
 *
 * @param params - The parameters to load the profile
 * @returns The profile filled with values found in the configuration profile
 *
 * @throws Error
 * Thrown if the configuration file couldn't be found,
 * or if the specified profile can't be found.
 *
 * @public
 */

const loadProfileFromConfigurationFile = params => {
  const filePath = (params == null ? void 0 : params.filepath) ?? resolveConfigurationFilePath();

  if (typeof filePath !== 'string' || filePath.length === 0) {
    throw new Error('Could not find the path to the configuration file.');
  }

  const configs = loadConfigurationFromFile(filePath);
  const profileName = (params == null ? void 0 : params.profileName) ?? 'default';
  const profileMap = configs[profileName];

  if (typeof profileMap !== 'object') {
    throw new Error(`Could not find the desired profile '${profileName}' in the configuration file.`);
  }

  return {
    accessKey: profileMap.access_key,
    apiURL: profileMap.api_url,
    defaultOrganizationId: profileMap.default_organization_id,
    defaultProjectId: profileMap.default_project_id,
    defaultRegion: profileMap.default_region,
    defaultZone: profileMap.default_zone,
    secretKey: profileMap.secret_key
  };
};

exports.loadProfileFromConfigurationFile = loadProfileFromConfigurationFile;
exports.loadProfileFromEnvironmentValues = loadProfileFromEnvironmentValues;
